/*
 * Copyright(C) OASIS(R) 2005,2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.
 */
package org.oasisopen.sdo.helper;

import org.oasisopen.sdo.DataObject;
import org.oasisopen.sdo.Type;

/**
 * A Factory for creating DataObjects.
 * The created DataObjects are not connected to any other DataObjects.
 */
public interface DataFactory
{

  /**
   * Create a DataObject of the Type specified by typeName with the given package uri.
   * If the <code>uri</code> is <code>null</code> or <code>""</code>, then a type with null
   * uri will be looked up.
   * @param uri The uri of the Type.
   * @param typeName The name of the Type.
   * @return the created DataObject.
   * @throws IllegalArgumentException if the uri and typeName does
   *   not correspond to a Type this factory can instantiate.
   */
  DataObject create(String uri, String typeName);

  /**
   * Create a DataObject of the Type specified.
   * @param type The Type.
   * @return the created DataObject.
   * @throws IllegalArgumentException if the Type
   *   cannot be instantiated by this factory.
   */
  DataObject create(Type type);

}