/*
 * Copyright(C) OASIS(R) 2005,2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.
 */
package org.oasisopen.sdo.helper;

import java.util.Map;

/**
 * The HelperContextFactory is used to get instances of HelperContext.
 * @since SDO 3.0
 */
public interface HelperContextFactory {

    /**
     * <p>Create a new HelperContext in this implementation.  Once created the HelperContext
     * can be looked up as follows (Note if the identifier is null or "" it is not registered):</p>
     * <pre>SDO.getHelperContext(identifier);</pre>
     * @param identifier - A unique identifier that can be used to access the HelperContext.
     * @param properties - Properties required to initialize the HelperContext.
     * @return a HelperContext object
     * @throws IllegalArgumentException If a different HelperContext is already
     * registered with the specified identifier.
     */
    public HelperContext createHelperContext(String identifier, Map<String, Object> properties) throws IllegalArgumentException;

    /**
     * <p>Create a new HelperContext in this implementation.  Once created the HelperContext
     * can be looked up as follows (Note if the identifier is null or "" it is not registered):</p>
     * <pre>SDO.getHelperContext(identifier);</pre>
     * @param identifier - A unique identifier that can be used to access the HelperContext.
     * @param classLoader - Used to resolve static instance classes when referenced by name.
     * @param properties - Properties required to initialize the HelperContext.
     * @return a HelperContext object
     * @throws IllegalArgumentException If a different HelperContext is already
     * registered with the specified identifier.
     */
    public HelperContext createHelperContext(String identifier, ClassLoader classLoader, Map<String, Object> properties) throws IllegalArgumentException;

}