/*
 * Copyright(C) OASIS(R) 2005,2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.
 */
package org.oasisopen.sdo.helper;

import java.util.List;

import org.oasisopen.sdo.Type;

/**
 * A helper for defining, retrieving and instantiating types based on
 * introspecting Java classes.
 */
public interface JavaHelper
{

  /**
   * Return the Type for this interfaceClass or null if not found.
   * @param interfaceClass is the interface for the DataObject's Type -
   *   type.getInstanceClass();
   * @return the Type for this interfaceClass or null if not found.
   */
  Type getType(Class<?> interfaceClass);

  /**
   * Introspect a class and use the result as the basis for defining a type.
   * The Type is available through {@link TypeHelper#getType} methods.
   * If a conflicting definition of a type with the same name already exists,
   * it is returned and no new definition takes place. Referenced classes are also
   * introspected, and corresponding types created, as needed.
   * @param type the class defining the type.
   * @return the defined Type.
   * @throws IllegalArgumentException if the Type could not be defined.
   */
  Type define(Class<?> type);

  /**
   * Introspect a list of classes and use the result as the basis for defining types.
   * The Types are available through {@link TypeHelper#getType} methods.
   * The output list will contain, for every item in the input list, either
   * the Type newly defined or a pre-existing Type in case a Type with the
   * given name already exists,  followed by any other types defined as a
   * result of this call.
   * Referenced classes are also introspected, and corresponding types created, as needed.
   * @param types a List of classes representing the Types.
   * @return the defined Types.
   * @throws IllegalArgumentException if the Types could not be defined.
   */
  List<Type> define(List<Class<?>> types);

  /**
   * Create a DataObject supporting the given interface.
   * InterfaceClass is the interface for the DataObject's Type.
   * The DataObject created is an instance of the interfaceClass.
   * @param interfaceClass is the interface for the DataObject's Type.
   * @return the created DataObject.
   * @throws IllegalArgumentException if the instanceClass does
   *   not correspond to a Type this factory can instantiate.
   */
  <T> T create(Class<T> interfaceClass);

}