/*
 * Copyright(C) OASIS(R) 2005,2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.
 */
package org.oasisopen.sdo.helper;

import org.oasisopen.sdo.impl.Environment;

/**
 * Bootstrap class that provides access to a HelperContextFactory.
 * @since SDO 3.0
 */
public class SDO {

    /**
     * <p>Return the default HelperContextFactory.<p>
     * <pre>
     * SDO.getHelperContextFactory() == SDO.getHelperContextFactory();
     * </pre>
     * </p>
     */
    public static HelperContextFactory getHelperContextFactory() {
        return Environment.getInstance().getHelperContextFactory();
    }

    /**
     * <p>Return the HelperContextFactory for the specified implementation.</p>
     * <pre>
     * SDO.getHelperContextFactory(implName) == SDO.getHelperContextFactory(implName);
     * </pre>
     * </p>
     */
    public static HelperContextFactory getHelperContextFactory(String implName) {
        return Environment.getInstance().getHelperContextFactory(implName);
    }

    /**
     * <p>Return the built-in HelperContext with the null identifier.
     * <pre>
     * SDO.getDefaultHelperContext() == SDO.getDefaultHelperContext();
     * </pre>
     * </p>
     */
    public static HelperContext getDefaultHelperContext() {
        return Environment.getInstance().getDefaultHelperContext();
    }

    /**
     * <p>Return the HelperContext with specified identifier, if a HelperContext
     * has been registered with that identifier, otherwise return null.  Calling
     * this method with a null or empty string as the identifier is equivalent
     * to SDO.getDefaultHelperContext().
     * <pre>
     * SDO.getHelperContext(identifier) == SDO.getHelperContext(identifier);
     * SDO.getHelperContext(null) == SDO.getDefaultHelperContext();
     * SDO.getHelperContext("") == SDO.getDefaultHelperContext();
     * </pre>
     * </p>
     * @param identifier - The unique identified that was used when the
     * HelperContext was created.
     * @return The HelperContext registered with that identifier, if one was not
     * found then return null.
     */
    public static HelperContext getHelperContext(String identifier) {
        if(null == identifier || "".equals(identifier)) {
            return Environment.getInstance().getDefaultHelperContext();
        } else {
            return Environment.getInstance().getHelperContext(identifier);
        }
    }

}